==> xm-charts-react-1.0.6.tgz: package/src/components/PieChart/index.js <==
import React, { PureComponent } from 'react'
import NoData from '../../NoData'
import PropTypes from 'prop-types'

import ReactEchartsCore from 'echarts-for-react/lib/core'
import echarts from 'echarts/lib/echarts'
import 'echarts/lib/chart/pie'
import 'echarts/lib/component/legend'
import 'echarts/lib/component/legendScroll'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'

import { titleTextStyle, pieSeriesConfig } from '../itemDefaultConfig'

class PieChart extends PureComponent {
  getOption() {
    const {
      config: { title, toolbox, legend, tooltip, showTitle, series, ...otherConfig },
    } = this.props

    return {
      title: {
        ...titleTextStyle,
        show: showTitle, // title.show优先级高于showTitle
        ...title,
      },
      tooltip: {
        trigger: 'item',
        formatter: '{a} <br/>{b}: {c} ({d}%)',
        ...tooltip,
      },
      legend: {
        top: 'bottom',
        type: 'scroll',
        itemGap: 15,
        icon: 'pin',
        ...legend,
      },
      toolbox: {
        ...toolbox,
      },
      series: (series || []).map(item => ({ ...pieSeriesConfig, ...item })),
      ...otherConfig,
    }
  }

  getEchartsInstance() {
    if (!this.chartRef) return

    return this.chartRef.getEchartsInstance()
  }

  saveRef = node => {
    this.chartRef = node
  }

  render() {
    const {
      config: { series },
      ...rest
    } = this.props

    if (!series.length) {
      return <NoData />
    }

    return (
      <ReactEchartsCore
        echarts={echarts}
        notMerge
        ref={this.saveRef}
        option={this.getOption()}
        {...rest}
      />
    )
  }
}

PieChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  showTitle: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  config: PropTypes.object,
}

PieChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  showTitle: false,
  config: {
    title: { text: '' },
    series: [
      {
        data: [
          {
            name: '示意1',

            value: 200,
          },
          {
            name: '示意2',
            value: 600,
          },
        ],
      },
    ],
  },
}

export default PieChart

==> xm-charts-react-1.0.8.tgz: package/src/components/PieChart/index.js <==
import React, { PureComponent } from 'react'
import Empty from '../Empty'
import PropTypes from 'prop-types'

import ReactEchartsCore from 'echarts-for-react/lib/core'
import echarts from 'echarts/lib/echarts'
import 'echarts/lib/chart/pie'
import 'echarts/lib/component/legend'
import 'echarts/lib/component/legendScroll'
import 'echarts/lib/component/tooltip'
import 'echarts/lib/component/title'

import { titleTextStyle, pieSeriesConfig } from '../itemDefaultConfig'

class PieChart extends PureComponent {
  getOption() {
    const {
      config: { title, toolbox, legend, tooltip, showTitle, series, ...otherConfig },
    } = this.props

    return {
      title: {
        ...titleTextStyle,
        show: showTitle, // title.show优先级高于showTitle
        ...title,
      },
      tooltip: {
        trigger: 'item',
        formatter: '{a} <br/>{b}: {c} ({d}%)',
        ...tooltip,
      },
      legend: {
        top: 'bottom',
        type: 'scroll',
        itemGap: 15,
        icon: 'pin',
        ...legend,
      },
      toolbox: {
        ...toolbox,
      },
      series: (series || []).map((item) => ({ ...pieSeriesConfig, ...item })),
      ...otherConfig,
    }
  }

  getEchartsInstance() {
    if (!this.chartRef) return

    return this.chartRef.getEchartsInstance()
  }

  saveRef = (node) => {
    this.chartRef = node
  }

  render() {
    const {
      config: { series },
      ...rest
    } = this.props

    if (!series.length) {
      return <Empty />
    }

    return (
      <ReactEchartsCore
        echarts={echarts}
        notMerge
        ref={this.saveRef}
        option={this.getOption()}
        {...rest}
      />
    )
  }
}

PieChart.propTypes = {
  theme: PropTypes.oneOfType([PropTypes.string, PropTypes.object]),
  showTitle: PropTypes.bool,
  style: PropTypes.object,
  className: PropTypes.string,
  config: PropTypes.object,
}

PieChart.defaultProps = {
  style: {},
  classname: '',
  theme: 'macarons',
  showTitle: false,
  config: {
    title: { text: '' },
    series: [
      {
        data: [
          {
            name: '示意1',

            value: 200,
          },
          {
            name: '示意2',
            value: 600,
          },
        ],
      },
    ],
  },
}

export default PieChart
